google.load('maps', '3', 
{
	other_params: 'sensor=false'
});
google.setOnLoadCallback(initialize);

function get_locations(the_radius, zipcode)
{
	var result = new Array();
	$.ajax(
	{
		type: "POST",
		url: 'search.php',
		dataType: 'json',
		data: {'radius': the_radius, 'zipcode':zipcode},
		async: false,
		success: function(data)
		{
			result = data; 
		}
	});
	return result;
}

function initialize() 
{
	var the_radius 	= $('#the_radius').val();
	var zipcode 	= $('#the_zipcode').val();
	var ajax_result	= get_locations(the_radius, zipcode);
	
	if(ajax_result[0] != "none")
	{
		var locations 	= ajax_result[0]; // The locations
		var med_lat 	= ajax_result[1]; // Average latitude of all locations
		var med_long 	= ajax_result[2]; // Average longitude of all locations
		
		// Set the center of the map
		var myLatlng = new google.maps.LatLng(med_lat, med_long);
		// Initialize the map
		var myOptions = {
			zoom: 10,
			center: myLatlng,
			mapTypeId: google.maps.MapTypeId.ROADMAP
		}
		
		// Set the map to a desired div 
		map = new google.maps.Map(document.getElementById("map_canvas"), myOptions);
		// Initialize the markers array - is used to make the cluster
		var markers = [];
		// Parse the array with the locations
		for(id in locations) 
		{
			// Set a maxWitdh to the window (optional) 
			var infoWindow = new google.maps.InfoWindow({maxWidth : 200});
			
			// Set the coordonates of the new point
			var latLng = new google.maps.LatLng(locations[id].estate_lat, locations[id].estate_long);
			
			// Initialize the new marker
			var marker = new google.maps.Marker(
			{
				position: latLng,
				map: map,
				title: locations[id].estate_name,
				icon:'small_icon.png'
			});
			
			// The HTML that is shown in the window of each item (when the icon it's clicked)
			var html = "<div style=\"text-align:center\"><h3>" + locations[id].estate_name + "</h3>Zipcode: " + locations[id].estate_zipcode + "</div>";
			
			// Binds the infoWindow to the point
			bindInfoWindow(marker, map, infoWindow, html);
			// Add the marker to the array
			markers.push(marker);
		}
		// Make a cluster with the markers from the array
		var markerCluster = new MarkerClusterer(map, markers);
	}
	else
	{
		alert('No estates found!');
	}
	
}	

function bindInfoWindow(marker, map, infoWindow, html) 
{
	google.maps.event.addListener(marker, 'click', function() {
		infoWindow.setContent(html);
		infoWindow.open(map, marker);
		marker.setIcon('small_icon_hover.png');
	});
}

$(document).ready(function()
{
	$( "#radius_slider" ).slider({
		range: "min",
		min: 1,
		max: 100,
		step:1,
		value: 1,
		slide: function( event, ui ) 
		{
			// set the radius value
			$( "#the_radius" ).val(ui.value);
			// set the label with the new radius - Only for visual effect
			$( "#radius_label" ).html("Radius: <strong>" + ui.value + "km </strong>");
		},
		stop: function( event, ui ) {
			// reinitialize the map only when the user stopped sliding
			initialize();
		},
	});
	$('#the_zipcode').change(function() 
	{
		// reinitialize the map when the zipcode changes
		initialize();
	});
});